/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "infowidget.h"
#include "testwidget.h"
#include "resultswidget.h"
#include "infodialog.h"
#include "answerslistitem.h"
#include "testgui.h"
#include "tableitem.h"
#include "testselector.h"

#include <qpixmap.h>
#include <qlayout.h>
#include <qtextview.h>
#include <qlistview.h>
#include <qwidget.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qtable.h>
#include <qheader.h>
#include <qlabel.h>
#include <qsizepolicy.h>
#include <qpe/resource.h>
#include <qapplication.h>
#include <qstatusbar.h>
#include <qmenubar.h>


/*Class InfoWidget implementation*/
InfoWidget::InfoWidget(QWidget *parent, const char *name): QWidget(parent, name) {
	layInfo = new QVBoxLayout(this);
    displayText = new QTextView(this);
 	QBrush paper;
  	paper.setPixmap(Resource::loadPixmap("handtest/marble.png"));
   	if(paper.pixmap() != 0)
    	displayText->setPaper(paper);
     else
     	displayText->setPaper(white);
     layInfo->addWidget(displayText);
}

void InfoWidget::setText(QString text) {
	displayText->setText(text);
}

void InfoWidget::clearContent() {
	displayText->setText("");
}

InfoWidget::~InfoWidget() {
	delete displayText;
    delete layInfo;
}

/*Class TestWidget implementation*/
TestWidget::TestWidget(QWidget *parent, const char *name ): QWidget(parent, name) {
    layTest = new QVBoxLayout(this);

    questionText = new QTextView(this, "question's text");
	layTest->addWidget(questionText);

    answersView = new QListView(this);
    answersView->setResizePolicy(QListView::AutoOneFit);
    answersView->setMaximumSize(QSize(235, 115));
    answersView->resize(235, 115);
	answersView->setSelectionMode(QListView::NoSelection);
 	answersView->setFocusPolicy(QListView::NoFocus);
	answersView->addColumn("Choose your answer:");
    layTest->addWidget(answersView);
	connect(answersView, SIGNAL(clicked(QListViewItem *)),
					this, SLOT(checkAnswer(QListViewItem *)));
	connect(this, SIGNAL(clear()), this, SLOT(clearComponent()));
}

TestWidget::~TestWidget() {
	delete questionText;
    delete answersView;
    delete layTest;
}

void TestWidget::setQuestionText(QString qTxt) {
	questionText->setText(qTxt);
}

void TestWidget::addAnswerItem(QString aTxt, Question::AnswersType atype, bool checked) {
	AnswersListItem *item;
	if(atype == Question::CheckBox)
        item = new CheckBoxTypeItem(answersView, 0, aTxt, checked); //checkbox
	else //atype = Question::Radio
    	item = new RadioTypeItem(answersView, 0, aTxt, checked); //radio
    answerHeight = item->height();
}

void TestWidget::setAnswersViewGeometry() {
	answersView->setMaximumHeight((answersView->childCount() + 2) * answerHeight);
    update();
}

/*This method is used to check a list view item if the user selects the pixmap
  or the text for the current item(a possible answer)*/
void TestWidget::checkAnswer(QListViewItem * itemSelected) {
	if(itemSelected != NULL) {
    	AnswersListItem *item = (AnswersListItem *)itemSelected;
		item->changeIcon();
	}
}

QListViewItem *TestWidget::getFirstAnswer() {
	answersView->setSorting(0,TRUE);
    answersView->sort();
    return answersView->firstChild();
}

void TestWidget::clearComponent() {
	questionText->setText("");
    answersView->clear();
}

/*Class ResultsWidget implementation*/
ResultsWidget::ResultsWidget(QWidget *parent): QFrame(parent) {
	testResults = new InfoWidget(this, "test results");
    QFont boldFont;

    boldFont.setWeight(QFont::Bold);
    infoBut = new QPushButton(this, "informations button");
    infoBut->setFont(boldFont);
    infoBut->setText("More Info");

    dismBut = new QPushButton(this, "dismiss button");
    dismBut->setFont(boldFont);
    dismBut->setText("Dismiss");

    connect(dismBut, SIGNAL(clicked()), this, SIGNAL(close()));
    connect(infoBut, SIGNAL(clicked()), this, SIGNAL(info()));
}

ResultsWidget::~ResultsWidget() {
	delete testResults;
    delete dismBut;
}

void ResultsWidget::setText(QString s) {
	testResults->setText(s);
}
void ResultsWidget::clearContent() {
	testResults->clearContent();
}

void ResultsWidget::setGeometry(QRect r) {
	QFrame::setGeometry(r);
    //testResults->setFixedSize(230, 200);
    testResults->resize(r.width(), (3 * r.height())/4 + 8);
    //setting the button geometry
    int buttAreaY = testResults->height()+3;
    //int buttAreaHeight = r.height() - buttAreaY;
    int x = testResults->width()/4;
    int y = buttAreaY;
    int buttWidth = x;
    int buttHeight = r.height()/10;
    infoBut->setGeometry(QRect(x-10,y,buttWidth, buttHeight));
    dismBut->setGeometry(QRect(2*x+10, y, buttWidth, buttHeight));
}

/*Class InfoDialog implementation*/
InfoDialog::InfoDialog(QWidget *parent, const char *name, int rowsTable):
				QMainWindow(parent, name) {

	setCaption("Test results per question");
    table = new QTable(rowsTable, 2, this, "question results");
    table->setSelectionMode(QTable::NoSelection);
    QHeader *header = table->horizontalHeader();
   	header->setLabel(0, "Status", 100);
    header->setLabel(1, "Explanations", 105);
    header->setResizeEnabled(FALSE);
    header= table->verticalHeader();
   	header->setResizeEnabled(FALSE);
 	connect(table, SIGNAL(clicked(int, int, int, const QPoint&)),
  		this, SIGNAL(details(int, int)));
    //resize((97*qApp->desktop()->width())/100, (80*qApp->desktop()->height())/100);
	resize((98*qApp->desktop()->width())/100, (88*qApp->desktop()->height())/100);
    setCentralWidget(table);
}

void InfoDialog::setTableItem(int row, QString status, bool s) {
	table->setItem(row, 0,
   				new StatusTableItem(table, QTableItem::Never, status, s));
	table->setItem(row, 1,
   				new QTableItem(table, QTableItem::Never," View details "));
}

InfoDialog::~InfoDialog() {
	delete table;
}
