/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "countdowntimer.h"
#include <qbrush.h>
#include <qlayout.h>


CountDownTimer::CountDownTimer(const QColor& bgd,
								QWidget *parent,
								const char *name):QLCDNumber(parent, name){

    QBrush foreground(black);
    QBrush button(white);
    QBrush light(black);
    QBrush dark(black);
	QBrush mid(black);QBrush text(black);QBrush bright_text(black);
    QBrush base(black); QBrush background(bgd);
    QColorGroup lcdColors(foreground, button, light, dark,
    						mid,text, bright_text,base,background);
    QPalette lcdPalette(lcdColors, lcdColors, lcdColors);
	setPalette(lcdPalette);
	setSegmentStyle(QLCDNumber::Filled);
}


void CountDownTimer::setTime(int time, QString unit) {
    int h = 0, m = 0, s = 0;
	if(unit == "sec") {
 		h = time / 3600; m = (time%3600)/ 60; s = (time%3600) % 60;
    }
    else if(unit == "min") {
    	h = time / 60; m = time % 60;
    }
    else {//unit = "h"
    	h = time;
    }
    currentTime = QTime(h,m,s);
    if(h != 0)
    	setNumDigits(8);
    else
    	setNumDigits(5);
    showTime();
	timer = startTimer(1000);
    active = TRUE;
}

void CountDownTimer::resetTimer() {
	currentTime = QTime(0, 0,0);
    showTime();
    active = FALSE;
}
void CountDownTimer::showTime(){
	display(currentTime.toString());
}

void CountDownTimer::stopTimer() {
	killTimer(timer);
    timer = -1;
    resetTimer();
}

bool CountDownTimer::isActive() {
	return active;
}

void CountDownTimer::timerEvent(QTimerEvent *e) {
	if(e->timerId() == timer) {
    	if(currentTime.hour() == 0 &&
        	currentTime.minute() == 0 &&
            currentTime.second() == 0) {
            stopTimer();
            emit timeKeeperEnded();
     	}
		else {
    		currentTime = currentTime.addSecs(-1);
        	showTime();
        }
    }

}
