/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "test.h"

/*Class Answer implementation*/
Answer::Answer(QString aText, bool aValue) {
	answerText = aText;
	answerValue = aValue;
    userAnswerValue = FALSE;
}

void Answer::setAnswerText(QString text) {
	answerText = text;
}

QString Answer::getAnswerText() const{
	return answerText;
}

void Answer::setAnswerValue(bool value) {
	answerValue = value;
}

bool Answer::getAnswerValue() const{
	return answerValue;
}

void Answer::setUserAnswerValue(bool value) {
	userAnswerValue = value;
}

bool Answer::getUserAnswerValue() const {
	return userAnswerValue;
}

Answer& Answer::operator = (Answer& answer) {
    if(this != &answer){
    	answerText = answer.answerText;
        answerValue = answer.answerValue;
        userAnswerValue = answer.userAnswerValue;
    }
    return *this;
}

Answer* Answer::operator = (Answer* answer) {
	if(this != answer) {
		answerText = answer->answerText;
		answerValue = answer->answerValue;
        userAnswerValue = answer->userAnswerValue;
	}
	return this;
}

/*Class Question implementation*/
Question::Question(QString qText) {
	questionText = qText;
    answers = new AnswersList();
    userAnswer = FALSE;
}

Question::~Question() {
	 if(answers)
		delete answers;
}

Question& Question::operator= (Question& q){
	if(this != &q) {
    	questionText = q.questionText;
        answers = q.answers;
        name = q.name;
        duration = q.duration;
        userAnswer = q.userAnswer;
    }
    return *this;
}

Question *Question::operator= (Question *q) {
	if(this != q) {
    	questionText = q->questionText;
        answers = q->answers;
        name = q->name;
        score = q->score;
        duration = q->duration;
        userAnswer = q->userAnswer;
    }
    return this;
}

void Question::insertAnswer(const Answer *answer) {
	answers->append(*answer);
}

AnswersIterator Question::begin() {
	return answers->begin();
}

AnswersIterator Question::end() {
	return answers->end();
}

int Question::getAnswersNumber() {
	return answers->count();
}

void Question::setQuestionText(QString text){
	questionText = text;
}

QString Question::getQuestionText() const {
	return questionText;
}

void Question::setName(QString name) {
	this->name = name;
}

QString Question::getName() const {
	return name;
}

void Question::setScore(float s) {
	score = s;
}

float Question::getScore() const {
	return score;
}

void Question::setDuration(int d) {
	duration = d;
}

int Question::getDuration() const {
	return duration;
}

void Question::setDurationUnit(QString unit){
	durationUnit = unit;
}

QString Question::getDurationUnit() const {
	return durationUnit;
}

void Question::setUserAnswer(bool value) {
	userAnswer = value;
}

bool Question::getUserAnswer() const {
	return userAnswer;
}

void Question::setExplanations(QString e) {
	explanations = e;
}

QString Question::getExplanations(){
	return explanations;
}

void Question::setAnswerType(Question::AnswersType at) {
	atype = at;
}

Question::AnswersType Question::getAnswerType() const {
	return atype;
}


/*Class TestBySections implementation*/
TestBySections::TestBySections(QString name) {
	sectionName = name;
    questions = new QuestionsList();
}

TestBySections::~TestBySections() {
	if(questions)
		delete questions;
}

void TestBySections::insertQuestion(const Question *question) {
	questions->append(*question);
}

TestBySections *TestBySections::operator=(TestBySections *ts) {
	if(this != ts) {
    	sectionName = ts->sectionName;
        questions = ts->questions;
        score = ts->score;
        duration = ts->duration;
    }
    return this;
}

QuestionsIterator TestBySections::begin() {
	return questions->begin();
}

QuestionsIterator TestBySections::end() {
	return questions->end();
}

int TestBySections::getQuestionsNumber() {
	return questions->count();
}

void TestBySections::setSectionName(QString name) {
	sectionName = name;
}

QString TestBySections::getSectionName() const {
	return sectionName;
}

void TestBySections::setScore(float val) {
	score = val;
}

float TestBySections::getScore() const {
	return score;
}

void TestBySections::setObtainedScore(float score) {
	obtainedScore = score;
}

float TestBySections::getObtainedScore() const {
	return obtainedScore;
}

void TestBySections::setDuration(int val) {
	duration = val;
}

int TestBySections::getDuration() const {
	return duration;
}

void TestBySections::setDurationUnit(QString unit){
	durationUnit = unit;
}

QString TestBySections::getDurationUnit() const {
	return durationUnit;
}


void TestBySections::setUserCorectAnswers(int value) {
	userCorectAnswers = value;
}

int TestBySections::getUserCorectAnswers() const {
	return userCorectAnswers;
}



/*Class Test implementation*/
Test::Test(QString name) {
	testName = name;
    test = new TestList();
}

Test::~Test(){
	if(test)
    	delete test;
}

Test* Test::operator = (Test* t) {
	if(this != t)
    	testName = t->testName;
        test = t->test;
    return this;
}

void Test::insertTest(const TestBySections *ts) {
	test->append(*ts);
}

TestIterator Test::begin() {
	return test->begin();
}

TestIterator Test::end() {
	return test->end();
}

int Test::getSectionsNumber() {
	return test->count();
}

void Test::setTestName(QString name) {
	testName = name;
}

QString Test::getTestName() {
	return testName;
}

void Test::setTotalScore(float score) {
	totalScore = score;
}

float Test::getTotalScore() const {
	return totalScore;
}

void Test::setBaremScore(float score) {
	baremScore = score;
}

float Test::getBaremScore() const {
	return baremScore;
}

void Test::setQuestionsNumber(int val) {
	questionsNumber = val;
}

int Test::getQuestionsNumber() const {
	return questionsNumber;
}

