/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef TEST_H
#define TEST_H

#include <qstring.h>
#include <qvaluelist.h>

class Answer;
class Question;
class TestBySections;
class Test;

typedef QValueList<Answer> AnswersList;
typedef QValueListIterator<Answer> AnswersIterator;
typedef QValueList<Question> QuestionsList;
typedef QValueListIterator<Question> QuestionsIterator;
typedef QValueList<TestBySections> TestList;
typedef QValueListIterator<TestBySections> TestIterator;

class Answer {
public:
	Answer(QString text = QString::null, bool val = FALSE);
	void setAnswerText(QString);
	QString getAnswerText() const;
	void setAnswerValue(bool);
	bool getAnswerValue() const;
    void setUserAnswerValue(bool);
    bool getUserAnswerValue() const;
	Answer *operator = (Answer *);
    Answer& operator = (Answer&);

private:
	QString answerText;
	bool answerValue;
    bool userAnswerValue;
};

class Question {
public:
	Question(QString qText = QString::null);
	~Question();
	void insertAnswer(const Answer *);
	AnswersIterator begin();
	AnswersIterator end();
	int getAnswersNumber();
	void setQuestionText(QString text);
	QString getQuestionText() const;
    void setName(QString);
    QString getName() const;
    void setScore(float);
    float getScore() const;
	void setDuration(int);
    int getDuration() const;
    void setDurationUnit(QString);
    QString getDurationUnit() const;
    void setUserAnswer(bool);
    bool getUserAnswer() const;
    void setExplanations(QString);
    QString getExplanations();
    Question *operator= (Question *);
    Question& operator= (Question&);
    enum AnswersType {Radio, CheckBox};
    void setAnswerType(AnswersType);
    AnswersType getAnswerType() const;
private:
	QString questionText;
    QString explanations;
	AnswersList *answers;
    AnswersType atype;
    QString name;
	float score;
	int duration;
    QString durationUnit;
    bool userAnswer;
};

class TestBySections {
public:
	TestBySections(QString name = QString::null);
	~TestBySections();
	void insertQuestion(const Question *);
	QuestionsIterator begin();
	QuestionsIterator end();
	int getQuestionsNumber();
	void setSectionName(QString);
	QString getSectionName() const;
    void setScore(float);
	float getScore() const;
    void setObtainedScore(float);
    float getObtainedScore() const;
    void setDuration(int);
    int getDuration() const;
    void setDurationUnit(QString);
    QString getDurationUnit() const;
    void setUserCorectAnswers(int);
    int getUserCorectAnswers() const;
    TestBySections* operator=(TestBySections *);

private:
	QString sectionName;
	QuestionsList *questions;
	float score;
    float obtainedScore;
	int duration;
    QString durationUnit;
    int userCorectAnswers;
};

class Test {
public:
	Test(QString name = QString::null);
	~Test();
	void insertTest(const TestBySections *);
	TestIterator begin();
	TestIterator end();
	int getSectionsNumber();
	void setTestName(QString name);
    QString getTestName();
    void setTotalScore(float);
    float getTotalScore() const;
    void setBaremScore(float);
    float getBaremScore() const;
    void setQuestionsNumber(int);
    int getQuestionsNumber() const;
    Test* operator = (Test*);

private:
	QString testName;
    int questionsNumber;
	TestList *test;
	float totalScore;
    float baremScore;
	int totalDuration;
};

#endif
