/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include <qlayout.h>
#include <qlabel.h>
#include <qprogressbar.h>
#include <qtoolbutton.h>
#include <qstatusbar.h>
#include <qwidgetstack.h>
#include <qpe/resource.h>
#include <qmessagebox.h>
#include <qtextview.h>
#include <qapplication.h>
#include <qmenubar.h>

#include "testgui.h"
#include "infowidget.h"
#include "xmlprocessor.h"
#include "testwidget.h"
#include "infodialog.h"
#include "resultswidget.h"
#include "answerslistitem.h"
#include "countdowntimer.h"

bool exitSection;
/*
 *  Constructs a MainForm which is a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 */
TestGUI::TestGUI( QWidget* parent,  const char* name, WFlags fl )
    			: QMainWindow( parent, name, fl){
    (void)statusBar();
    boldFont.setWeight(QFont::Bold);
    if ( !name )
		setName( "testgui" );
    parent->parentWidget()->setCaption("HandTest");
	//setting the geometry

    progress = 0;
    maxprogress = 0;
    prog = new QProgressBar(statusBar(), "progress");
    prog->setTotalSteps(100);
    prog->setCenterIndicator(TRUE);
    prog->setProgress(progress);
    statusBar()->addWidget(prog, 0, TRUE);

    //adding to the status bar a label for message status
    message = new QLabel(statusBar(), "current message");
    message->setAlignment(AlignCenter);
    message->setFont(boldFont);
    statusBar()->addWidget(message,1, TRUE);

    time_status = new QLabel(statusBar(), "timeleft");
    time_status->setAlignment(AlignCenter);
    time_status->setFont(boldFont);
    statusBar()->addWidget(time_status,1, TRUE);
    iniBGDColor = time_status->backgroundColor();

    controls = new QLabel(statusBar(), "test controls");
    controls->setAlignment(AlignCenter);
    statusBar()->addWidget(controls,2, TRUE);

    QHBoxLayout *hlay = new QHBoxLayout(controls);

    toolbCancel = new QToolButton(controls, "cancel");
    toolbCancel->setIconSet(Resource::loadPixmap("handtest/t-cancel"));
    toolbCancel->setEnabled(FALSE);
    connect(toolbCancel, SIGNAL(clicked()), this, SLOT(cancelTest()));
    hlay->addWidget(toolbCancel);

    toolbPrevious = new QToolButton(controls, "previous");
    toolbPrevious->setIconSet(Resource::loadPixmap("handtest/t-previous"));
    toolbPrevious->setEnabled(FALSE);
    hlay->addWidget(toolbPrevious);
    connect(toolbPrevious, SIGNAL(clicked()), this, SLOT(previousQuestion()));

    toolbSN = new QToolButton(controls, "start/next");
    toolbSN->setIconSet(Resource::loadPixmap("handtest/t-start"));
    toolbSN->setEnabled(FALSE);
    connect(toolbSN, SIGNAL(clicked()), this, SLOT(nextQuestion()));
    hlay->addWidget(toolbSN);

    connect(this, SIGNAL(changeToolbSNIcon(int)), this, SLOT(changedSNIcon(int)));
    connect(this, SIGNAL(changeProgressBar(int)), this, SLOT(setProgress(int)));
    //start test->load the xml information into Test container
    connect(this, SIGNAL(startTest()), this, SLOT(loadTest()));
    connect(this, SIGNAL(finishTest()), this, SLOT(displayResults()));

    stack = new QWidgetStack(this);
    setCentralWidget(stack);

    infoTestWidget = new InfoWidget(stack, "info widget");
    stack->addWidget(infoTestWidget, 0);

    testWidget = new TestWidget(stack, "test widget");
    stack->addWidget(testWidget, 1);
    connect(this, SIGNAL(clean()), testWidget, SIGNAL(clear()));

    resultsWidget = new ResultsWidget(stack);
    stack->addWidget(resultsWidget, 2);
    connect(resultsWidget, SIGNAL(close()), this , SLOT(closeTest()));
    connect(resultsWidget, SIGNAL(info()), this, SLOT(globalInfo()));

    widget = new QWidget(stack, "empty widget");
    stack->addWidget(widget, 3);
    xmlParser = 0; cdt = 0;
    currentQuestion = 0;
    detailsTab = 0;infoDial = 0;
    type = TestSelector::TimerTest;
}

void TestGUI::setFileName(QString& f) {
    fileName = f;
    openTest();
}

void TestGUI::openTest() {
    //here to choose a file
    message->setText("loading test");
    if(xmlParser) {
    	delete xmlParser;
    }
    xmlParser = new XMLProcessor(fileName, this, "xml parser");
    if(!xmlParser->load()) {
	if(xmlParser) {
        	delete xmlParser;
        	xmlParser = 0;
        }
    	return;
    }
    stack->raiseWidget(infoTestWidget);
    message->setText("Loaded.");
    testInfo = xmlParser->getTestInfo();
    infoTestWidget->setText(testInfo);
    toolbSN->setEnabled(TRUE);
}

/*This method is used to change the icon from the toolbar
  when a test is started or finished */
void TestGUI::changedSNIcon(int t) {
	if(!t)
		toolbSN->setPixmap(Resource::loadPixmap("handtest/t-next"));
	else
		toolbSN->setPixmap(Resource::loadPixmap("handtest/t-start"));
}

void TestGUI::changeTestType() {
	type = ((TestSelector *)(parentWidget()->parentWidget()))->getCurrentTestType();
}

void TestGUI::nextQuestion() {
    if(type == TestSelector::TrainerTest)
    	nextTrainerQuestion();
    else //type = TestSelector::TimerTest
    	nextTimerQuestion();
}

void TestGUI::loadTest() {
    test = new Test();
    //loading the test from the file
    xmlParser->process(test);
	((TestSelector *)(parentWidget()->parentWidget()))->testLoaded=1;
}


bool TestGUI::questionIterator() {
    if(tit != test->end()) {
    	qit = (*tit).begin();
        if(type == TestSelector::TimerTest)
        	currentSectionQuestion = 0;
      	return true;
    }
    else if(currentQuestion == test->getQuestionsNumber()) {
    	    currentQuestion++;
    	    emit changeProgressBar(100);
    	    exitSection = FALSE;
    	    computeResults();
    	    emit finishTest();
    }
   return false;
}

void TestGUI::nextTrainerQuestion() {
	if(currentQuestion == 0) {
    	emit startTest();
        tit = test->begin();
        if(!questionIterator()) {
        	cancelTest();
    		return;
        }
        ((TestSelector *)parentWidget()->parentWidget())->enableMenuOpenActions(FALSE);
 		((TestSelector *)parentWidget()->parentWidget())->enableTrainerTool(FALSE);
        stack->raiseWidget(testWidget);

        emit changeProgressBar(0);
        emit changeToolbSNIcon(currentQuestion);
        toolbCancel->setEnabled(TRUE);
        detailsTab = new QString[test->getQuestionsNumber()];
    }else { //evaluate the current question and after that display another
    	if(currentQuestion == 1)
    		((TestSelector *)parentWidget()->parentWidget())->toolbInform->setEnabled(TRUE);
    	evalCurrentQuestion();
        emit clean();
    	//getting to the next question
        emit changeProgressBar(100/test->getQuestionsNumber());
		detailsTab[currentQuestion - 1] = detailsString();
  		qit++;
    }
	if(qit == (*tit).end()) {
    	++tit;
     	if(!questionIterator())
      		return;
    }
    currentQuestion++;
    //post the question in the Widget
    postQuestion();
}

void TestGUI::prepareQuestionsTimer() {
	if(!cdt && type == TestSelector::TimerTest) {
        box = new QVBoxLayout(time_status);
       	cdt = new CountDownTimer(iniBGDColor,
        						time_status, "timer");
        cdt->setFixedSize(time_status->width(), time_status->height());
        cdt->resize(time_status->width(), time_status->height());
		box->addWidget(cdt);
        cdt->show();
        connect(cdt, SIGNAL(timeKeeperEnded()), this, SLOT(currentTimeEnded()));
    }
    while(cdt->isActive()) {
    	cdt->stopTimer();
    }
}

void TestGUI::nextTimerQuestion() {
	if(currentQuestion == 0) {
    	emit startTest();
        tit = test->begin();
        //display section's direction-user must press OK button
        if(!sectionDirectionsDialog()) {
        	delete test;
         	return;
        }
        prepareQuestionsTimer();
        if(!questionIterator()) {
        	cancelTest();
    		return;
        }
		((TestSelector *)parentWidget()->parentWidget())->enableMenuOpenActions(FALSE);
    	((TestSelector *)parentWidget()->parentWidget())->enableTrainerTool(FALSE);
        stack->raiseWidget(testWidget);

        emit changeProgressBar(0);
        //a test must be started
		emit changeToolbSNIcon(currentQuestion);
        toolbCancel->setEnabled(TRUE);
        detailsTab = new QString[test->getQuestionsNumber()];
	}
    else { //evaluate the current question and after that display another
    	while(cdt->isActive() && ttype == QuestionTimer) {
     		cdt->stopTimer();
         }
       evalCurrentQuestion();
       if(!toolbPrevious->isEnabled() && ttype == SectionTimer)
            	toolbPrevious->setEnabled(TRUE);
        emit clean();
    	//getting to the next question
        emit changeProgressBar(100/test->getQuestionsNumber());
        if(detailsTab[currentQuestion - 1] == QString::null)
        	detailsTab[currentQuestion - 1] = detailsString();

        if(ttype == SectionTimer && exitSection) {
        	for(++qit; qit != (*tit).end(); ++qit) {
            	currentQuestion++;
            	emit changeProgressBar(100/test->getQuestionsNumber());
                if(detailsTab[currentQuestion - 1] == QString::null)
        			detailsTab[currentQuestion - 1] = detailsString();
            }
        } else
     		qit++;
    }
	if(qit == (*tit).end()) {
    	if(ttype == SectionTimer) {
        	while(cdt->isActive())
            	cdt->stopTimer();
         	toolbPrevious->setEnabled(FALSE);
        }
        message->clear();
        ++tit;
     	if(!questionIterator())
      		return;
		stack->raiseWidget(widget);
    	//changing the central widget
     	if(!sectionDirectionsDialog())
      		if(cancelTest() == QMessageBox::Yes) return;
            	stack->raiseWidget(testWidget);
    }
    currentQuestion++; currentSectionQuestion++;
    //post the question in the Widget
    postQuestion();
    //QuestionTimer
    if(sectionTime == 0) {
    	ttype = QuestionTimer;
    	timerDuration = (*qit).getDuration();
		if(timerDuration) {
			timeUnit =(*qit).getDurationUnit();
  			//qDebug("Current duration = %d", timerDuration);
     		//qDebug("units = %s", timeUnit.latin1());
       		cdt->setTime(timerDuration, timeUnit);
		}
   	} else {//time per section
        	if(!cdt->isActive()) {
        		ttype = SectionTimer;
        		cdt->setTime(sectionTime, timeUnit);
            	exitSection = FALSE;
        	}
	}
}

void TestGUI::postQuestion() {
	testWidget->setQuestionText((*qit).getQuestionText());
    //getting the answers
    Question::AnswersType atype = (*qit).getAnswerType();
    for(ait = (*qit).begin(); ait != (*qit).end(); ait++) {
    	testWidget->addAnswerItem((*ait).getAnswerText(), atype,
     							  (*ait).getUserAnswerValue());
    }
    if(type == TestSelector::TrainerTest)
		message->setText(QString("Q:%1/%2")
    					.arg(currentQuestion)
    					.arg(test->getQuestionsNumber()));
    else
    	message->setText(QString("Q:%1/%2")
    					.arg(currentSectionQuestion)
    					.arg((*tit).getQuestionsNumber()));

}

void TestGUI::evalCurrentQuestion(){
	QListViewItem *item =testWidget->getFirstAnswer();
    bool corect = TRUE;
	//evaluate the current answer
	for(ait = (*qit).begin();ait !=(*qit).end(); ait++) {
		if(item && (*ait).getAnswerText() == item->text(0)) {
			(*ait).setUserAnswerValue(((AnswersListItem *)item)->isChecked());
   			corect = corect &&
       		((*ait).getAnswerValue() == (*ait).getUserAnswerValue());
		}
  		else
    		qDebug("Watch out a null item!");
		item = item->nextSibling();
  }
  //qDebug("Corect answer=%d", corect);
  if(type == TestSelector::TrainerTest)
  	setAnswerStatus(corect);
  (*qit).setUserAnswer(corect);
}

QString TestGUI::sectionDetails() {
	QString text;
    QString format;
    text.append(format.sprintf("<center><b>%s</b></center><br>",
    				(*tit).getSectionName().latin1()));
    text.append(format.sprintf("This section has %d questions.<br><br>",
    				(*tit).getQuestionsNumber()));
   	sectionTime = (*tit).getDuration();
    if(!sectionTime)
    	text.append("<ul><li>Each question has an individual time to be resolved.</li>"
    			    "<li>The time alocated for each question, will be displayed in the"
                    " status bar.</li></ul><br>");
    else {
    	//qDebug("units = %s", (*tit).getDurationUnit().latin1());
        timeUnit = (*tit).getDurationUnit();
        text.append(format.sprintf("<ul><li>The time alocated for this section is %d %s</li>",
        							sectionTime, timeUnit.latin1()));
        text.append("<li>If you have enough time, you can return to change "
        			"the answers for the previous questions.</li></ul>");
    }
    text.append("Press <b>OK</b> button to proceed.");
    return text;
}


int TestGUI::sectionDirectionsDialog() {
	QDialog directions(this, "first section direction", TRUE);
    directions.setCaption("Section directions:");
    QVBoxLayout vbox(&directions);
    QTextView text(&directions, " sections directions");
    text.setText(sectionDetails());
    vbox.addWidget(&text);
    directions.resize(235, 180);
    return directions.exec();
}

void TestGUI::currentTimeEnded() {
    //TimerTest test type
    if(ttype == SectionTimer) { //ttype = SectionTimer
        //if the section is not ended
        exitSection = TRUE;
	}
 	nextTimerQuestion();
}


void TestGUI::previousQuestion() {
	evalCurrentQuestion();
    emit clean();
    emit changeProgressBar(-100/test->getQuestionsNumber());
	qit--;
 	currentQuestion--; currentSectionQuestion--;
    if(qit == (*tit).begin())
    	toolbPrevious->setEnabled(FALSE);
    postQuestion();
}


void TestGUI::setAnswerStatus(bool value) {
    QString colorName;
    QString msg;
	if(value) {
    	// good answer
    	colorName = "#00FF00";
        msg = "Ok";
    }
	else {
    	//wrong answer
    	colorName = "#FF0000";
        msg = "Failed";
    }
	time_status->setBackgroundColor(QColor(colorName));
    time_status->setText(QString("Q:%1 %2")
    								.arg(currentQuestion)
                                    .arg(msg));
}


int TestGUI::cancelTest() {
	QMessageBox msgBox("Quiting the test","Quit current test?",
    					QMessageBox::Information,
                        QMessageBox::Yes | QMessageBox::Default,
                        QMessageBox::No | QMessageBox::Escape,
                        QMessageBox::NoButton,
                        this, "cancel test message dialog", TRUE);
	msgBox.setFixedSize(200, 100);
    int choice = msgBox.exec();
	if( choice == QMessageBox::Yes){
 		message->setText("test ended.");
        emit clean();
    	cleanComponents();
        stack->raiseWidget(infoTestWidget);
        ((TestSelector *)parentWidget()->parentWidget())->enableMenuOpenActions(TRUE);
    	((TestSelector *)parentWidget()->parentWidget())->enableTrainerTool(TRUE);
    	prepareNewTest();
    }
    return choice;
}

void TestGUI::cleanComponents(){
    emit changeProgressBar(0);
    message->clear();
    time_status->clear();
    if(type == TestSelector::TimerTest) {
    	while(cdt->isActive()) {
            cdt->stopTimer();
        }
        delete cdt; delete box;
        cdt = 0;
    }
    time_status->setBackgroundColor(iniBGDColor);
	((TestSelector *)(parentWidget()->parentWidget()))->testLoaded = 0;
}

void TestGUI::prepareNewTest() {
	//changing the state for toolbCancel& toolbSN
    emit changeToolbSNIcon(currentQuestion);
    toolbCancel->setEnabled(FALSE);
    //partial or final tests
    currentQuestion = 0;
    if(test) delete test;
    if(detailsTab) delete []detailsTab;

    if(((TestSelector *)parentWidget()->parentWidget())->toolbInform->isEnabled()) {
    	((TestSelector *)parentWidget()->parentWidget())->toolbInform->setEnabled(FALSE);
    }
    if(toolbPrevious->isEnabled())
    	toolbPrevious->setEnabled(FALSE);
}

QString TestGUI::detailsString(){
	QString detStr;
    QString atxt;
    QString userChoice;
    QString format;
    detStr.append("<b><big>Question:</big></b><br>");
    detStr.append((*qit).getQuestionText());
    detStr.append("<hr><b><big>Answers:</big></b><br>");
    for(ait = (*qit).begin(); ait != (*qit).end(); ++ait) {
    	atxt = (*ait).getAnswerText();
		detStr.append(atxt + "<br>");
        if((*ait).getUserAnswerValue())
        	userChoice.append(format.sprintf(" (%c) ", atxt.at(0).latin1()));
    }
    detStr.append("<hr><b><big>Your answer: </big></b>");
    detStr.append(userChoice);
    detStr.append("<hr><b><big>Explanations:</big></b><br>");
    detStr.append((*qit).getExplanations());
    return detStr;
}

void TestGUI::informTest() {
	if(type == TestSelector::TrainerTest)
    	questionDetails(currentQuestion-2, 1);
    else
    	globalInfo();
}

void TestGUI::questionDetails(int row, int col) {
	if(col == 1) {
		//QDialog dial(this, "question details", TRUE);
		QWidget* dial = new QWidget(0, "question details");
    	dial->setCaption(QString("Question: %1").arg(row+1));
        QVBoxLayout* vbox = new QVBoxLayout(dial);
    	QTextView* detText = new QTextView(dial, "question details");
		detText->setText(detailsTab[row]);
        vbox->addWidget(detText);
        dial->resize((98*qApp->desktop()->width())/100, (88*qApp->desktop()->height())/100);
        detText->resize(dial->width(), dial->height());
        //dial.exec();
		dial->show();
    }
}


void TestGUI::setProgress(int p) {
	if(p == 0) {
    	progress = maxprogress = 0;
        prog->reset();
        message->clear();
    }
    else if(p < 100) {
		progress += p;
        if(progress > maxprogress)
			maxprogress = progress;
	}
    else
    	progress = maxprogress = 100;
	prog->setProgress(maxprogress);
}

void TestGUI::computeResults() {
	bool answerValue;
	obTotalScore = totalScore = 0;
 	totalCorectAnswers = 0; //total corect answers
	for(tit = test->begin(); tit != test->end(); ++tit) {
    	obSectionScore = sectionScore = 0;
        sectionCorectAnswers = 0;
    	for(qit = (*tit).begin(); qit != (*tit).end(); ++qit) {
        	answerValue = (*qit).getUserAnswer();
  			if(answerValue) {
  				sectionCorectAnswers++;
    			obSectionScore += (*qit).getScore();
  			}
  			sectionScore += (*qit).getScore();
		}
		//qDebug("section Corect answers:%d", sectionCorectAnswers);
   		(*tit).setUserCorectAnswers(sectionCorectAnswers);
      	totalCorectAnswers += sectionCorectAnswers;
        //qDebug("section score = %g", sectionScore);
        //qDebug("obtained score = %g", obSectionScore);
        if(sectionScore) {
        	if((*tit).getScore() != sectionScore)
        		(*tit).setScore(sectionScore);
        }else{
        	sectionScore = (*tit).getScore();
            if(obSectionScore == 0) {
        		obSectionScore = ((*tit).getScore() *sectionCorectAnswers)
           						/ (*tit).getQuestionsNumber();
				//qDebug("obscore = %g",obSectionScore);
            }
    	}
        //qDebug("section score = %g", sectionScore);
        //qDebug("obtained score = %g", obSectionScore);
        (*tit).setObtainedScore(obSectionScore);
  		obTotalScore += obSectionScore;
        totalScore += sectionScore;
    }
    //qDebug("total obtained score %g", obTotalScore);
    //qDebug("total corect answers %d", totalCorectAnswers);
    //qDebug("Total score %g", totalScore);
    if(totalScore && totalScore != test->getTotalScore())
        	test->setTotalScore(totalScore);
}

void TestGUI::displayResults() {
    message->setText("Results");
	stack->raiseWidget(resultsWidget);

    resultsWidget->setGeometry(
    	QRect(0,0, parentWidget()->width(), parentWidget()->height()));
    resultsWidget->setText(constructTextResults());
    //change the play test icon and disable it
    emit changeToolbSNIcon(currentQuestion);
    toolbSN->setEnabled(FALSE);
    toolbCancel->setEnabled(FALSE);
    if(toolbPrevious->isEnabled())
    	toolbPrevious->setEnabled(FALSE);
    ((TestSelector *)parentWidget()->parentWidget())->toolbInform->setEnabled(TRUE);
}

void TestGUI::closeTest() {
	resultsWidget->clearContent();
	//clear the table infodial
    if(infoDial) {delete infoDial; infoDial = 0;}
    if(detailsTab) {delete []detailsTab; detailsTab = 0;}
    cleanComponents();
    prepareNewTest();
    ((TestSelector *)parentWidget()->parentWidget())->enableTrainerTool(TRUE);
    emit closeTestGUI();
}

QString TestGUI::constructTextResults() {
	QString text;
    QString textFormat;
	//test result antet
    text.append("<b><big>Test Results:</big></b><br><hr>");
    text.append(textFormat.sprintf("<b><center>%s</center></b><br>",
    					test->getTestName().latin1()));
	text.append(textFormat.sprintf("<b>Total test score: </b> %g <br>"
 								   "<b>Obtained score: </b> %g <br>",
                                   test->getTotalScore(), obTotalScore));
    text.append(textFormat.sprintf("<b>Questions number: </b> %d <br>"
    							   "<b>Corect answers: </b> %d <br>",
                                   test->getQuestionsNumber(), totalCorectAnswers));
    for(tit = test->begin(); tit != test->end(); ++tit) {
    	text.append(textFormat.sprintf("<b>Section name: </b> <br> %s",
        								(*tit).getSectionName().latin1()));
		text.append(textFormat.sprintf("<ul><li>Questions: %d Answered: %d</li>"
  										"<li>Score: %g Obtained: %g</li></ul>",
                                        (*tit).getQuestionsNumber(),
                                        (*tit).getUserCorectAnswers(),
                                        (*tit).getScore(),
                                        (*tit).getObtainedScore()));
    }
	text.append("<b>Status: </b>");
    if(obTotalScore >= test->getBaremScore())
    	textFormat = "Passed.";
	else
    	textFormat = "Failed";
	text.append(textFormat);
	return text;
}

void TestGUI::globalInfo() {
	int rows = test->getQuestionsNumber();
 	if(!infoDial) {
  		infoDial = new InfoDialog(this, "test information",rows);
    	connect(infoDial, SIGNAL(details(int, int)),
  				this, SLOT(questionDetails(int, int)));
    }
    //details on every question from the test
    initTable();
	infoDial->show();
}

void TestGUI::initTable() {
	QString status;
    int count = 0;
    bool s;
	for(tit = test->begin(); tit != test->end(); ++tit)
    	for(qit = (*tit).begin(); qit != (*tit).end(); ++qit) {
			s = (*qit).getUserAnswer();
            if(s)
            	status="  Corect answer ";
			else
            	status="  Wrong answer ";
            infoDial->setTableItem(count, status,s);
			//detailsTab[count] = detailsString();
            count++;
 		}
}

//for testing only
void TestGUI::displayTestContent(Test *test) {
	TestIterator tit;
    QuestionsIterator qit;
    AnswersIterator ait;

    qDebug("test name = %s", test->getTestName().latin1());
    qDebug("section number = %d", test->getSectionsNumber());
    qDebug("number of questions = %d", test->getQuestionsNumber());
    for(tit = test->begin(); tit != test->end(); ++tit) {
    	qDebug("section name = %s", (*tit).getSectionName().latin1());
    	qDebug("score= %g", (*tit).getScore());
        qDebug("duration = %d",(*tit).getDuration());
        qDebug("question number=%d", (*tit).getQuestionsNumber());
        for(qit = (*tit).begin(); qit != (*tit).end(); ++qit) {
			qDebug("question name = %s", (*qit).getName().latin1());
            qDebug("\tquestion score = %g", (*qit).getScore());
            qDebug("\tquestion duration = %d", (*qit).getDuration());
            qDebug("\tquestion test = %s", (*qit).getQuestionText().latin1());
			for(ait = (*qit).begin(); ait != (*qit).end(); ++ait) {
				qDebug("\t\tanswer=%s", (*ait).getAnswerText().latin1());
                qDebug("\t\t\tanswer value = %d", (*ait).getAnswerValue());
			}
		}
    }
}




