/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef TESTGUI_H
#define TESTGUI_H

#include <qmainwindow.h>
#include <qfont.h>
#include <qcolor.h>
#include <qlayout.h>

#include "test.h"
#include "testselector.h"

class QToolBar;
class QToolButton;
class QLabel;
class QProgressBar;
class QWidgetStack;
class InfoWidget;
class XMLProcessor;
class Test;
class TestWidget;
class InfoDialog;
class ResultsWidget;
class CountDownTimer;

class TestGUI: public QMainWindow {
	Q_OBJECT
public:
	TestGUI( QWidget* parent = 0, const char* name = 0, WFlags fl = WType_TopLevel);
	void setFileName(QString&);

signals:
	void changeToolbSNIcon(int);
	void startTest();
 	void finishTest();
    void changeProgressBar(int);
    void clean();
    void closeTestGUI();

public slots:
	void closeTest();
protected slots:
	void changedSNIcon(int);
	void nextQuestion();
    bool questionIterator();
    void setProgress(int);
    int cancelTest();
	void informTest();
    void previousQuestion();
    void changeTestType();

private slots:
	void loadTest();
	void globalInfo();
	void questionDetails(int, int);
    void displayResults();
    void currentTimeEnded();

protected:
	void openTest();

private:
	void nextTrainerQuestion();
    void nextTimerQuestion();
    void cleanComponents();
    void prepareNewTest();
    void evalCurrentQuestion();
    void setAnswerStatus(bool);
    void postQuestion();
	QString detailsString();
	void computeResults();
    QString constructTextResults();
    void initTable();
    int sectionDirectionsDialog();
    QString sectionDetails();
    void prepareQuestionsTimer();
    void displayTestContent(Test *);

    QToolButton *toolbInform;
	QToolButton *toolbSN;
	QToolButton *toolbCancel;
    QToolButton *toolbPrevious;

    QString fileName;
    XMLProcessor *xmlParser;
    Test *test;
    TestIterator tit;
    QuestionsIterator qit;
    AnswersIterator ait;

    QString testInfo;
    QWidgetStack *stack;
    InfoWidget *infoTestWidget;
    TestWidget *testWidget;
    ResultsWidget *resultsWidget;
    InfoDialog *infoDial;
    QWidget *widget;

    QBoxLayout *box;
    CountDownTimer *cdt;

    QString *detailsTab;
    //status bar
	QFont boldFont;
 	QLabel *message;
	QColor iniBGDColor;
    QLabel *time_status;
    QLabel *controls;
    int progress;
    int maxprogress;
 	QProgressBar *prog;

    int currentQuestion;
    int currentSectionQuestion;
    float obSectionScore;
    float sectionScore;
    float obTotalScore;
    float totalScore;
    int sectionCorectAnswers;
    int totalCorectAnswers;
    int sectionTime;
    int timerDuration;
    QString timeUnit;
    enum TimerType {QuestionTimer, SectionTimer};
    TimerType ttype;
    TestSelector::TestType type;
};

#endif

