/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include <qaction.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qmenubar.h>
#include <qapplication.h>
#include <qmessagebox.h>
#include <qwidgetstack.h>
#include <qpe/resource.h>

#include "testselector.h"
#include "testgui.h"


TestSelector::TestSelector( QString fileName, QWidget *parent, const char *name,
							int wFlags):QMainWindow(parent, name, wFlags){
	this->fileName = fileName;
    if ( !name )
		setName( "test selector" );

	resize(qApp->desktop()->width(), qApp->desktop()->height());

	// actions
	fileOpenAction = new QAction( this, "fileOpenAction" );
	fileOpenAction->setIconSet(QIconSet(Resource::loadPixmap("handtest/fileopen")));
	fileOpenAction->setText("Open");
	fileOpenAction->setMenuText("Open...");

	//fileExitAction = new QAction( this, "fileExitAction" );
	//fileExitAction->setText("Exit");
 	//fileExitAction->setMenuText("Exit");

	/*
  	helpContentsAction = new QAction( this, "helpContentsAction" );
    helpContentsAction->setText("Contents");
    helpContentsAction->setMenuText("Contents...");
    */

    helpAboutAction = new QAction( this, "helpAboutAction" );
    helpAboutAction->setText("About");
    helpAboutAction->setMenuText("About...");

    	// toolbars
    toolbar = new QToolBar(this, "toolbar");
	toolbar->setHorizontalStretchable(TRUE);
	toolbar->setOrientation(Qt::Horizontal);
	setToolBarsMovable(FALSE);
    	// menubar
 	menubar = new QMenuBar( toolbar, "menubar" );

  	fileMenu = new QPopupMenu( this );
    fileOpenAction->addTo( fileMenu );
    //fileMenu->insertSeparator();
    //fileExitAction->addTo( fileMenu );
    menubar->insertItem("File", fileMenu );

    helpMenu = new QPopupMenu( this );
    //helpContentsAction->addTo( helpMenu );
    //helpMenu->insertSeparator();
    helpAboutAction->addTo( helpMenu );
    menubar->insertItem("Help", helpMenu );

    toolbar->addSeparator();


	toolbOpen = new QToolButton(Resource::loadPixmap("handtest/fileopen"),"open file selector",
    				QString::null, this, SLOT(openFileSelector()), toolbar, "open file selector");
    toolbTrainer = new QToolButton(Resource::loadPixmap("handtest/t_trainer"),"test type",
    				QString::null,this, SLOT(testTrainer()), toolbar, "test type");
    toolbTrainer->setToggleButton(TRUE);
    toolbar->addSeparator();

	toolbInform = new QToolButton(Resource::loadPixmap("handtest/informations"),
    					"question details",
    					QString::null, this, SLOT(informTest()), toolbar, "question details");
	toolbInform->setEnabled(FALSE);

	wstack = new QWidgetStack(this);
    setCentralWidget(wstack);

    fileSelector = new FileSelector("application/x-htest", wstack, "fs");
    fileSelector->setNewVisible(FALSE);
    fileSelector->setCloseVisible(FALSE);
    wstack->addWidget(fileSelector, 0);
    connect(fileSelector, SIGNAL(closeMe()), this, SLOT(closeFileSelector()));
    connect(fileSelector, SIGNAL(fileSelected(const DocLnk&)),
    		this, SLOT(openFile(const DocLnk&)));

    testWidget = new TestGUI(wstack, "test gui",0);
	wstack->addWidget(testWidget, 1);
    connect(testWidget, SIGNAL(closeTestGUI()), this, SLOT(openFileSelector()));
	connect(this, SIGNAL(testTypeChanged()), testWidget, SLOT(changeTestType()));

 	wstack->raiseWidget(fileSelector);

    connect( fileOpenAction, SIGNAL(activated()), this, SLOT(openFileSelector()));
    //connect( fileExitAction, SIGNAL(activated()), this, SLOT(fileExit() ));
    //connect( helpContentsAction, SIGNAL( activated() ), this, SLOT( helpContents() ) );
    connect( helpAboutAction, SIGNAL(activated()), this, SLOT(helpAbout()));
	connect(this, SIGNAL(inform()), testWidget, SLOT(informTest()));
	connect(this, SIGNAL(releaseResources()), testWidget, SLOT(closeTest()));
    enableMenuOpenActions(FALSE);
	testLoaded = 0;
}

TestSelector::~TestSelector() {
}

void TestSelector::closeEvent(QCloseEvent* e) {
	switch(QMessageBox::information(this, "Leaving the application",
								    "Do you want to exit?", "Yes", "No", 0,1)) {
		case 0:
			e->accept();
			break;
		case 1:
			e->ignore();
			break;
	}
}

void TestSelector::setDocument(const QString& fileref) {
	fileName = fileref;
	openFile();
}

void TestSelector::openFile() {
	//change the current Widget
	/*
	if(testLoaded) {
		emit releaseResources();
		QMessageBox::warning(this, "HandTest", "Resources released");
	}*/
    closeFileSelector();
	testWidget->setFileName(fileName);
}

void TestSelector::openFileSelector() {
	setCaption("HandTest");
	//getting the test list
    wstack->raiseWidget(fileSelector);
    enableMenuOpenActions(FALSE);
}

void TestSelector::openFile(const DocLnk& f) {
    fileName = f.file();
    openFile();
}

void TestSelector::testTrainer() {
	if(toolbTrainer->isOn())
    	type = TestSelector::TrainerTest;
    else
    	type = TestSelector::TimerTest;
    emit testTypeChanged();
}

TestSelector::TestType TestSelector::getCurrentTestType() {
	return type;
}

void TestSelector::closeFileSelector() {
	wstack->raiseWidget(testWidget);
    enableMenuOpenActions(TRUE);
}

void TestSelector::helpAbout() {
	QString author("Copyright(c) 2002-Violeta Diaconu\n");
    QString text;
    text.append("Application for knowledge testing\n").append(author);
    text.append(QString("violeta_diaconu@yahoo.com").rightJustify(author.length()-1, ' '));
	QMessageBox::about(this, "HandTest", text);
}

void TestSelector::enableMenuOpenActions(bool value){
	fileOpenAction->setEnabled(value);
    toolbOpen->setEnabled(value);
}

void TestSelector::enableTrainerTool(bool value) {
	toolbTrainer->setEnabled(value);
}

void TestSelector::informTest() {
	emit inform();
}

/*This method is used for application exit*/
void TestSelector::fileExit() {
	qApp->exit();
}



