/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include<qmessagebox.h>
#include <qtextstream.h>

#include "xmlprocessor.h"
#include "test.h"

XMLProcessor::XMLProcessor(const QString fileName,
			QWidget *p, const char *name):QWidget(p, name) {
	xmlFileName = fileName;
    parent = p;
}

bool XMLProcessor::load() {
	QFile xmlFile(xmlFileName);
    if(!xmlFile.open(IO_ReadOnly)){
    	QMessageBox::critical(parent,
			        tr("Critical Error"),
			        tr("Cannot open file %1").arg(xmlFileName));
	return false;
    }
    QTextStream ts(&xmlFile);
    QXmlInputSource xmlInput(ts);
    QXmlSimpleReader reader;
    reader.setContentHandler(&handler);
    
    MyQXmlErrorHandler errorHandler;
    reader.setErrorHandler(&errorHandler);

    if(!reader.parse(xmlInput)) {
    	QMessageBox::critical(parent,
			        tr("Critical Error"),
			        tr("Parsing Error for file %1").arg(xmlFileName));
		xmlFile.close();
		return false;
	}
    xmlFile.close();
    return true;
}

QString XMLProcessor::getTestInfo() {
	Node *node = handler.firstNode()->firstChild();
    //<test name="name">
    QString result;
    result.append("<b>");
    result.append(node->attribute("name"));
    result.append("</b>");
    result.append("<hr>");
    node = node->firstChild();
    if(node)
    	//getting info
    	result.append(node->data());
	return result;
}

void XMLProcessor::process(Test *t) {
    //getting the test tag
	Node *node = handler.firstNode()->firstChild();
    //qDebug("TagName:%s", node->tagName().latin1());
    t->setTestName(node->attribute("name"));
    t->setTotalScore(node->attribute("score").toFloat());
    t->setBaremScore(node->attribute("barem").toFloat());
    getTestSections(t, node);
}

void XMLProcessor::getTestSections(Test *t, Node *parentNode) {
	Node *node = parentNode->firstChild()->nextNode();
    int qnumber = 0;
    while(node) {
    	TestBySections *sectionTest = new TestBySections(node->attribute("name"));
        //getting the section attributes
		sectionTest->setScore(node->attribute("score").toFloat());
        sectionTest->setDuration(node->attribute("duration").toInt());
        sectionTest->setDurationUnit(node->attribute("units"));
  		getSectionQuestions(sectionTest,node);
        t->insertTest(sectionTest);
        qnumber += sectionTest->getQuestionsNumber();
    	if(node == parentNode->lastChild())
        	break;
        else
        	node = node->nextNode();
    }
    t->setQuestionsNumber(qnumber);
}

void XMLProcessor::getSectionQuestions(TestBySections * sectionTest,Node *parentNode) {
	Node *node = parentNode->firstChild();
    while(node) {
		Question *quest = new Question;
        quest->setName(node->attribute("name"));
        quest->setScore(node->attribute("score").toFloat());
        quest->setDuration(node->attribute("duration").toInt());
        quest->setDurationUnit(node->attribute("units"));
        //getting the question text
        quest->setQuestionText(node->firstChild()->data());
        //de construit intrebarea
        getQuestionAnswers(quest, node->firstChild()->nextNode());
        quest->setExplanations(node->lastChild()->data());
        sectionTest->insertQuestion(quest);
        if(node == parentNode->lastChild())
        	break;
        else
        	node = node->nextNode();
    }
}

void XMLProcessor::getQuestionAnswers(Question *question, Node *parentNode) {
	int cAnsw = 0;
	Node *node = parentNode->firstChild();
    QString value;
    while(node) {
    	Answer *answer = new Answer;
        //qDebug("answer text %s",node->data().latin1());
        answer->setAnswerText(node->data());
        value = node->attribute("valid");
        if(value.lower() == "true") {
        	answer->setAnswerValue(TRUE);
            cAnsw++;
        }
		else
        	answer->setAnswerValue(FALSE);
        //qDebug("value = %s", value.latin1());
        question->insertAnswer(answer);
        if(node == parentNode->lastChild())
        	break;
		else
        	node = node->nextNode();
    }
    if(cAnsw == 1)
    	//radioButton - a single correct answer
        question->setAnswerType(Question::Radio);
    else
		//more than one correct answer
    	question->setAnswerType(Question::CheckBox);
}

XMLProcessor::~XMLProcessor() {
    //pentru a fi implementat
}


