/**********************************************************************
** Copyright (C) 2002 Diaconu Violeta.  All rights reserved.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact violeta_diaconu@yahoo.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef XMLPROCESSOR_H
#define XMLPROCESSOR_H

#include <qfile.h>
#include <qpe/xmlreader.h>
#include "test.h"

class XMLProcessor: public QWidget{
public:
    XMLProcessor(const QString xmlFileName,
    QWidget *parent = 0, const char *name = 0);
    ~XMLProcessor();
    bool load();
    QString getTestInfo();
    void process(Test *);
private:
	//to get the test sections
	void getTestSections(Test *, Node *);
    void getSectionQuestions(TestBySections *, Node *);
    void getQuestionAnswers(Question *, Node *);
private:
	QString xmlFileName;
	QWidget *parent;
	QFile xmlFile;
    XmlHandler handler;

};

class MyQXmlErrorHandler:public QXmlErrorHandler {
public:
	bool warning( const QXmlParseException& exception ) {
    	_errorString = exception.message();
        qDebug( "%s at %d:%d (%s : %s)", exception.message().latin1(),
        		exception.columnNumber(), exception.lineNumber(),
                exception.publicId().latin1(), exception.systemId().latin1());
    	return true;
    }

    bool error( const QXmlParseException& exception ) {
    	_errorString = exception.message();
        qDebug( "%s at %d:%d (%s : %s)", exception.message().latin1(),
        		exception.columnNumber(), exception.lineNumber(),
                exception.publicId().latin1(), exception.systemId().latin1());
        return true;
    }

    bool fatalError( const QXmlParseException& exception ) {
    	_errorString = exception.message();
    	qDebug( "%s at %d:%d (%s : %s)", exception.message().latin1(),
        		exception.columnNumber(), exception.lineNumber(),
                exception.publicId().latin1(), exception.systemId().latin1());
        return true;
    }

	QString errorString() {
		return _errorString;
    }

    virtual ~MyQXmlErrorHandler() {}

private:
	QString _errorString;
};
#endif
